@@ -2,13 +2,6 @@
 #include <gtkmm.h>
 #include <iostream>
 
-Gtk::Dialog* pDialog = 0;
-
-void on_dialog_button_clicked()
-{
-  pDialog->hide(); //hide() will cause Main::run() to end.
-}
-
 int main (int argc, char **argv)
 {
   Gtk::Main kit(argc, argv);
@@ -26,6 +19,7 @@ int main (int argc, char **argv)
   }
 
   //Get the Glade-instantiated Dialog:
+  Gtk::Dialog* pDialog = 0;
   refXml->get_widget("DialogBasic", pDialog);
   if(pDialog)
   {
@@ -34,7 +28,7 @@ int main (int argc, char **argv)
     refXml->get_widget("quit_button", pButton);
     if(pButton)
     {
-      pButton->signal_clicked().connect(SigC::slot(&on_dialog_button_clicked));
+      pButton->signal_clicked().connect(SigC::slot(*pDialog, &Gtk::Dialog::hide)); //hide() will cause main::run() to end.
     }
 
     kit.run(*pDialog);
